Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(279)

Unified Diff: chrome/browser/history/history_unittest.cc

Issue 10897033: Now with unit test fixes. [Try 2 with fixes for unit tests.] (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/themes/browser_theme_pack_unittest.cc » ('j') | chrome/test/ui/ui_test.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/history/history_unittest.cc
diff --git a/chrome/browser/history/history_unittest.cc b/chrome/browser/history/history_unittest.cc
index bd350efb2b618be9d631a5cc25135b9826c8a22a..e339004a972d55bff2a18aa7e7214e40a9faf195 100644
--- a/chrome/browser/history/history_unittest.cc
+++ b/chrome/browser/history/history_unittest.cc
@@ -937,13 +937,13 @@ TEST_F(HistoryTest, MostVisitedURLs) {
// history" example file or it will be imported on startup, throwing off timing
// measurements.
//
// See test/data/profiles/typical_history/README.txt for instructions on
// how to up the version.
TEST(HistoryProfileTest, TypicalProfileVersion) {
FilePath file;
ASSERT_TRUE(PathService::Get(chrome::DIR_TEST_DATA, &file));
file = file.AppendASCII("profiles");
- file = file.AppendASCII("typical_history");
+ file = file.AppendASCII("profile_with_default_theme");
file = file.AppendASCII("Default");
file = file.AppendASCII("History");
« no previous file with comments | « no previous file | chrome/browser/themes/browser_theme_pack_unittest.cc » ('j') | chrome/test/ui/ui_test.cc » ('J')
@@ -937,13 +937,13 @@ TEST_F(HistoryTest, MostVisitedURLs) {
// measurements.
//
-// See test/data/profiles/typical_history/README.txt for instructions on
-// how to up the version.
+// See test/data/profiles/profile_with_default_theme/README.txt for
+// instructions on how to up the version.
TEST(HistoryProfileTest, TypicalProfileVersion) {
FilePath file;

Powered by Google App Engine
This is Rietveld 408576698